# coding=utf-8
from ...Classes.Onderdeel.Ruigte import Ruigte


# Generated with OTLClassCreator. To modify: extend, do not edit
class VerstoordGrasland(Ruigte):
    """R1 - duinriet, kruipertje, gewone raket, bijvoet, fijnstraal spec., kleine brandnetel, boerenwormkruid, kamille spec., varkensgras, akkerdistel, klein kaasjeskruid, teunisbloem spec., honingklaver spec., grote kaardebol, stinkende ballote, kompassla, zeepkruid, wilde reseda, ijle dravik, kleine ooievaarsbek, kruldistel, slangenkruid, klein hoefblad, akkerwinde, kweek, heermoes, grote klaproos, herderstasje, paarse dovenetel, perzikkruid, vogelmuur, akkerkool"""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerstoordGrasland'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()
