# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlNetwerkelemModelnaam(KeuzelijstField):
    """Modelnamen voor Netwerkelementen."""
    naam = 'KlNetwerkelemModelnaam'
    label = 'Netwerkelement modelnaam'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlNetwerkelemModelnaam'
    definition = 'Modelnamen voor Netwerkelementen.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlNetwerkelemModelnaam'
    options = {
        '1322VD': KeuzelijstWaarde(invulwaarde='1322VD',
                                   label='1322VD',
                                   status='ingebruik',
                                   definitie='1322VD',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/1322VD'),
        '1511BA': KeuzelijstWaarde(invulwaarde='1511BA',
                                   label='1511BA',
                                   status='ingebruik',
                                   definitie='1511BA',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/1511BA'),
        '1515CXC': KeuzelijstWaarde(invulwaarde='1515CXC',
                                    label='1515CXC',
                                    status='ingebruik',
                                    definitie='1515CXC',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/1515CXC'),
        '2150': KeuzelijstWaarde(invulwaarde='2150',
                                 label='2150',
                                 status='ingebruik',
                                 definitie='2150',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/2150'),
        '3916': KeuzelijstWaarde(invulwaarde='3916',
                                 label='3916',
                                 status='ingebruik',
                                 definitie='3916',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/3916'),
        '3924': KeuzelijstWaarde(invulwaarde='3924',
                                 label='3924',
                                 status='ingebruik',
                                 definitie='3924',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/3924'),
        '3926': KeuzelijstWaarde(invulwaarde='3926',
                                 label='3926',
                                 status='ingebruik',
                                 definitie='3926',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/3926'),
        '3928': KeuzelijstWaarde(invulwaarde='3928',
                                 label='3928',
                                 status='ingebruik',
                                 definitie='3928',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/3928'),
        '3930': KeuzelijstWaarde(invulwaarde='3930',
                                 label='3930',
                                 status='ingebruik',
                                 definitie='3930',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/3930'),
        '3942': KeuzelijstWaarde(invulwaarde='3942',
                                 label='3942',
                                 status='ingebruik',
                                 definitie='3942',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/3942'),
        '4200Classic': KeuzelijstWaarde(invulwaarde='4200Classic',
                                        label='4200Classic',
                                        status='ingebruik',
                                        definitie='4200Classic',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/4200Classic'),
        '4200Micro': KeuzelijstWaarde(invulwaarde='4200Micro',
                                      label='4200Micro',
                                      status='ingebruik',
                                      definitie='4200Micro',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/4200Micro'),
        '4200RS': KeuzelijstWaarde(invulwaarde='4200RS',
                                   label='4200RS',
                                   status='ingebruik',
                                   definitie='4200RS',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/4200RS'),
        '5142': KeuzelijstWaarde(invulwaarde='5142',
                                 label='5142',
                                 status='ingebruik',
                                 definitie='5142',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/5142'),
        '5160': KeuzelijstWaarde(invulwaarde='5160',
                                 label='5160',
                                 status='ingebruik',
                                 definitie='5160',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/5160'),
        '5170': KeuzelijstWaarde(invulwaarde='5170',
                                 label='5170',
                                 status='ingebruik',
                                 definitie='5170',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/5170'),
        '5171': KeuzelijstWaarde(invulwaarde='5171',
                                 label='5171',
                                 status='ingebruik',
                                 definitie='5171',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/5171'),
        '6500-D14': KeuzelijstWaarde(invulwaarde='6500-D14',
                                     label='6500-D14',
                                     status='ingebruik',
                                     definitie='6500-D14',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/6500-D14'),
        '6500-D2': KeuzelijstWaarde(invulwaarde='6500-D2',
                                    label='6500-D2',
                                    status='ingebruik',
                                    definitie='6500-D2',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/6500-D2'),
        '6500-D7': KeuzelijstWaarde(invulwaarde='6500-D7',
                                    label='6500-D7',
                                    status='ingebruik',
                                    definitie='6500-D7',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/6500-D7'),
        '6500-S14': KeuzelijstWaarde(invulwaarde='6500-S14',
                                     label='6500-S14',
                                     status='ingebruik',
                                     definitie='6500-S14',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/6500-S14'),
        '6500-S32': KeuzelijstWaarde(invulwaarde='6500-S32',
                                     label='6500-S32',
                                     status='ingebruik',
                                     definitie='6500-S32',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/6500-S32'),
        '6500-S8': KeuzelijstWaarde(invulwaarde='6500-S8',
                                    label='6500-S8',
                                    status='ingebruik',
                                    definitie='6500-S8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/6500-S8'),
        'ADMU': KeuzelijstWaarde(invulwaarde='ADMU',
                                 label='ADMU',
                                 status='ingebruik',
                                 definitie='ADMU',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ADMU'),
        'AM1+': KeuzelijstWaarde(invulwaarde='AM1+',
                                 label='AM1+',
                                 status='ingebruik',
                                 definitie='AM1+',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/AM1+'),
        'AMC': KeuzelijstWaarde(invulwaarde='AMC',
                                label='AMC',
                                status='ingebruik',
                                definitie='AMC',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/AMC'),
        'AMS': KeuzelijstWaarde(invulwaarde='AMS',
                                label='AMS',
                                status='ingebruik',
                                definitie='AMS',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/AMS'),
        'AMU1slot': KeuzelijstWaarde(invulwaarde='AMU1slot',
                                     label='AMU1slot',
                                     status='ingebruik',
                                     definitie='AMU1slot',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/AMU1slot'),
        'AMU4slot': KeuzelijstWaarde(invulwaarde='AMU4slot',
                                     label='AMU4slot',
                                     status='ingebruik',
                                     definitie='AMU4slot',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/AMU4slot'),
        'NULL': KeuzelijstWaarde(invulwaarde='NULL',
                                 label='NULL',
                                 status='ingebruik',
                                 definitie='NULL',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/NULL'),
        'OMS': KeuzelijstWaarde(invulwaarde='OMS',
                                label='OMS',
                                status='ingebruik',
                                definitie='OMS',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/OMS'),
        'Other': KeuzelijstWaarde(invulwaarde='Other',
                                  label='Other',
                                  status='ingebruik',
                                  definitie='Other',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/Other'),
        'air': KeuzelijstWaarde(invulwaarde='air',
                                label='AIR',
                                status='ingebruik',
                                definitie='AIR',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/air'),
        'c1800': KeuzelijstWaarde(invulwaarde='c1800',
                                  label='C1800',
                                  status='ingebruik',
                                  definitie='C1800',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c1800'),
        'c2950': KeuzelijstWaarde(invulwaarde='c2950',
                                  label='C2950',
                                  status='ingebruik',
                                  definitie='C2950',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c2950'),
        'c2960': KeuzelijstWaarde(invulwaarde='c2960',
                                  label='C2960',
                                  status='ingebruik',
                                  definitie='C2960',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c2960'),
        'c3550': KeuzelijstWaarde(invulwaarde='c3550',
                                  label='C3550',
                                  status='ingebruik',
                                  definitie='C3550',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c3550'),
        'c3560': KeuzelijstWaarde(invulwaarde='c3560',
                                  label='C3560',
                                  status='ingebruik',
                                  definitie='C3560',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c3560'),
        'c3650': KeuzelijstWaarde(invulwaarde='c3650',
                                  label='C3650',
                                  status='ingebruik',
                                  definitie='C3650',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c3650'),
        'c3750': KeuzelijstWaarde(invulwaarde='c3750',
                                  label='C3750',
                                  status='ingebruik',
                                  definitie='C3750',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c3750'),
        'c3850': KeuzelijstWaarde(invulwaarde='c3850',
                                  label='C3850',
                                  status='ingebruik',
                                  definitie='C3850',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c3850'),
        'c880': KeuzelijstWaarde(invulwaarde='c880',
                                 label='C880',
                                 status='ingebruik',
                                 definitie='C880',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c880'),
        'c9300': KeuzelijstWaarde(invulwaarde='c9300',
                                  label='C9300',
                                  status='ingebruik',
                                  definitie='C9300',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/c9300'),
        'fgt': KeuzelijstWaarde(invulwaarde='fgt',
                                label='FGT',
                                status='ingebruik',
                                definitie='FGT',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/fgt'),
        'hiveap-122': KeuzelijstWaarde(invulwaarde='hiveap-122',
                                       label='HiveAP 122',
                                       status='ingebruik',
                                       definitie='HiveAP 122',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/hiveap-122'),
        'ie-1000': KeuzelijstWaarde(invulwaarde='ie-1000',
                                    label='IE-1000',
                                    status='ingebruik',
                                    definitie='IE-1000',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ie-1000'),
        'ie-2000': KeuzelijstWaarde(invulwaarde='ie-2000',
                                    label='IE-2000',
                                    status='ingebruik',
                                    definitie='IE-2000',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ie-2000'),
        'ie-3000': KeuzelijstWaarde(invulwaarde='ie-3000',
                                    label='IE-3000',
                                    status='ingebruik',
                                    definitie='IE-3000',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ie-3000'),
        'ie-4000': KeuzelijstWaarde(invulwaarde='ie-4000',
                                    label='IE-4000',
                                    status='ingebruik',
                                    definitie='IE-4000',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ie-4000'),
        'ir1100': KeuzelijstWaarde(invulwaarde='ir1100',
                                   label='IR1100',
                                   status='ingebruik',
                                   definitie='IR1100',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ir1100'),
        'ir800': KeuzelijstWaarde(invulwaarde='ir800',
                                  label='IR800',
                                  status='ingebruik',
                                  definitie='IR800',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ir800'),
        'lgx-rck-2-1u': KeuzelijstWaarde(invulwaarde='lgx-rck-2-1u',
                                         label='LGX-RCK-2-1U',
                                         status='ingebruik',
                                         definitie='LGX-RCK-2-1U',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/lgx-rck-2-1u'),
        'mar1030': KeuzelijstWaarde(invulwaarde='mar1030',
                                    label='MAR1030',
                                    status='ingebruik',
                                    definitie='MAR1030',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/mar1030'),
        'mar1040': KeuzelijstWaarde(invulwaarde='mar1040',
                                    label='MAR1040',
                                    status='ingebruik',
                                    definitie='MAR1040',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/mar1040'),
        'ml530': KeuzelijstWaarde(invulwaarde='ml530',
                                  label='ML530',
                                  status='ingebruik',
                                  definitie='ML530',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ml530'),
        'ml620': KeuzelijstWaarde(invulwaarde='ml620',
                                  label='ML620',
                                  status='ingebruik',
                                  definitie='ML620',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ml620'),
        'ml680': KeuzelijstWaarde(invulwaarde='ml680',
                                  label='ML680',
                                  status='ingebruik',
                                  definitie='ML680',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/ml680'),
        'nexus': KeuzelijstWaarde(invulwaarde='nexus',
                                  label='NEXUS',
                                  status='ingebruik',
                                  definitie='NEXUS',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/nexus'),
        'rs30': KeuzelijstWaarde(invulwaarde='rs30',
                                 label='RS30',
                                 status='ingebruik',
                                 definitie='RS30',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemModelnaam/rs30')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

