# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlNetwerkpoortGolflengte(KeuzelijstField):
    """Lijst van mogelijke golflengten waarop een Netwerkpoort kan communiceren."""
    naam = 'KlNetwerkpoortGolflengte'
    label = 'Netwerkpoort golflengte'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlNetwerkpoortGolflengte'
    definition = 'Lijst van mogelijke golflengten waarop een Netwerkpoort kan communiceren.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlNetwerkpoortGolflengte'
    options = {
        'C1310': KeuzelijstWaarde(invulwaarde='C1310',
                                  label='C1310',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/C1310'),
        'C1470': KeuzelijstWaarde(invulwaarde='C1470',
                                  label='C1470',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/C1470'),
        'C1490': KeuzelijstWaarde(invulwaarde='C1490',
                                  label='C1490',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/C1490'),
        'C1510': KeuzelijstWaarde(invulwaarde='C1510',
                                  label='C1510',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/C1510'),
        'C1530': KeuzelijstWaarde(invulwaarde='C1530',
                                  label='C1530',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/C1530'),
        'C1550': KeuzelijstWaarde(invulwaarde='C1550',
                                  label='C1550',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/C1550'),
        'C1570': KeuzelijstWaarde(invulwaarde='C1570',
                                  label='C1570',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/C1570'),
        'C1590': KeuzelijstWaarde(invulwaarde='C1590',
                                  label='C1590',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/C1590'),
        'C1610': KeuzelijstWaarde(invulwaarde='C1610',
                                  label='C1610',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/C1610'),
        'C850': KeuzelijstWaarde(invulwaarde='C850',
                                 label='C850',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/C850'),
        'D1528.77': KeuzelijstWaarde(invulwaarde='D1528.77',
                                     label='D1528.77',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1528.77'),
        'D1529.16': KeuzelijstWaarde(invulwaarde='D1529.16',
                                     label='D1529.16',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1529.16'),
        'D1529.55': KeuzelijstWaarde(invulwaarde='D1529.55',
                                     label='D1529.55',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1529.55'),
        'D1529.94': KeuzelijstWaarde(invulwaarde='D1529.94',
                                     label='D1529.94',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1529.94'),
        'D1530.33': KeuzelijstWaarde(invulwaarde='D1530.33',
                                     label='D1530.33',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1530.33'),
        'D1530.72': KeuzelijstWaarde(invulwaarde='D1530.72',
                                     label='D1530.72',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1530.72'),
        'D1531.12': KeuzelijstWaarde(invulwaarde='D1531.12',
                                     label='D1531.12',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1531.12'),
        'D1531.51': KeuzelijstWaarde(invulwaarde='D1531.51',
                                     label='D1531.51',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1531.51'),
        'D1531.90': KeuzelijstWaarde(invulwaarde='D1531.90',
                                     label='D1531.90',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1531.90'),
        'D1532.29': KeuzelijstWaarde(invulwaarde='D1532.29',
                                     label='D1532.29',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1532.29'),
        'D1532.68': KeuzelijstWaarde(invulwaarde='D1532.68',
                                     label='D1532.68',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1532.68'),
        'D1533.07': KeuzelijstWaarde(invulwaarde='D1533.07',
                                     label='D1533.07',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1533.07'),
        'D1533.47': KeuzelijstWaarde(invulwaarde='D1533.47',
                                     label='D1533.47',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1533.47'),
        'D1533.86': KeuzelijstWaarde(invulwaarde='D1533.86',
                                     label='D1533.86',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1533.86'),
        'D1534.25': KeuzelijstWaarde(invulwaarde='D1534.25',
                                     label='D1534.25',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1534.25'),
        'D1534.64': KeuzelijstWaarde(invulwaarde='D1534.64',
                                     label='D1534.64',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1534.64'),
        'D1535.04': KeuzelijstWaarde(invulwaarde='D1535.04',
                                     label='D1535.04',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1535.04'),
        'D1535.43': KeuzelijstWaarde(invulwaarde='D1535.43',
                                     label='D1535.43',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1535.43'),
        'D1535.82': KeuzelijstWaarde(invulwaarde='D1535.82',
                                     label='D1535.82',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1535.82'),
        'D1536.22': KeuzelijstWaarde(invulwaarde='D1536.22',
                                     label='D1536.22',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1536.22'),
        'D1536.61': KeuzelijstWaarde(invulwaarde='D1536.61',
                                     label='D1536.61',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1536.61'),
        'D1537.00': KeuzelijstWaarde(invulwaarde='D1537.00',
                                     label='D1537.00',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1537.00'),
        'D1537.40': KeuzelijstWaarde(invulwaarde='D1537.40',
                                     label='D1537.40',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1537.40'),
        'D1537.79': KeuzelijstWaarde(invulwaarde='D1537.79',
                                     label='D1537.79',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1537.79'),
        'D1538.19': KeuzelijstWaarde(invulwaarde='D1538.19',
                                     label='D1538.19',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1538.19'),
        'D1538.58': KeuzelijstWaarde(invulwaarde='D1538.58',
                                     label='D1538.58',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1538.58'),
        'D1538.98': KeuzelijstWaarde(invulwaarde='D1538.98',
                                     label='D1538.98',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1538.98'),
        'D1539.37': KeuzelijstWaarde(invulwaarde='D1539.37',
                                     label='D1539.37',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1539.37'),
        'D1539.77': KeuzelijstWaarde(invulwaarde='D1539.77',
                                     label='D1539.77',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1539.77'),
        'D1540.16': KeuzelijstWaarde(invulwaarde='D1540.16',
                                     label='D1540.16',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1540.16'),
        'D1540.56': KeuzelijstWaarde(invulwaarde='D1540.56',
                                     label='D1540.56',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1540.56'),
        'D1540.95': KeuzelijstWaarde(invulwaarde='D1540.95',
                                     label='D1540.95',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1540.95'),
        'D1541.35': KeuzelijstWaarde(invulwaarde='D1541.35',
                                     label='D1541.35',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1541.35'),
        'D1541.75': KeuzelijstWaarde(invulwaarde='D1541.75',
                                     label='D1541.75',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1541.75'),
        'D1542.14': KeuzelijstWaarde(invulwaarde='D1542.14',
                                     label='D1542.14',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1542.14'),
        'D1542.54': KeuzelijstWaarde(invulwaarde='D1542.54',
                                     label='D1542.54',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1542.54'),
        'D1542.94': KeuzelijstWaarde(invulwaarde='D1542.94',
                                     label='D1542.94',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1542.94'),
        'D1543.33': KeuzelijstWaarde(invulwaarde='D1543.33',
                                     label='D1543.33',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1543.33'),
        'D1543.73': KeuzelijstWaarde(invulwaarde='D1543.73',
                                     label='D1543.73',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1543.73'),
        'D1544.13': KeuzelijstWaarde(invulwaarde='D1544.13',
                                     label='D1544.13',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1544.13'),
        'D1544.53': KeuzelijstWaarde(invulwaarde='D1544.53',
                                     label='D1544.53',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1544.53'),
        'D1544.92': KeuzelijstWaarde(invulwaarde='D1544.92',
                                     label='D1544.92',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1544.92'),
        'D1545.32': KeuzelijstWaarde(invulwaarde='D1545.32',
                                     label='D1545.32',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1545.32'),
        'D1545.72': KeuzelijstWaarde(invulwaarde='D1545.72',
                                     label='D1545.72',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1545.72'),
        'D1546.12': KeuzelijstWaarde(invulwaarde='D1546.12',
                                     label='D1546.12',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1546.12'),
        'D1546.52': KeuzelijstWaarde(invulwaarde='D1546.52',
                                     label='D1546.52',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1546.52'),
        'D1546.92': KeuzelijstWaarde(invulwaarde='D1546.92',
                                     label='D1546.92',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1546.92'),
        'D1547.32': KeuzelijstWaarde(invulwaarde='D1547.32',
                                     label='D1547.32',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1547.32'),
        'D1547.72': KeuzelijstWaarde(invulwaarde='D1547.72',
                                     label='D1547.72',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1547.72'),
        'D1548.11': KeuzelijstWaarde(invulwaarde='D1548.11',
                                     label='D1548.11',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1548.11'),
        'D1548.51': KeuzelijstWaarde(invulwaarde='D1548.51',
                                     label='D1548.51',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1548.51'),
        'D1548.91': KeuzelijstWaarde(invulwaarde='D1548.91',
                                     label='D1548.91',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1548.91'),
        'D1549.32': KeuzelijstWaarde(invulwaarde='D1549.32',
                                     label='D1549.32',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1549.32'),
        'D1549.72': KeuzelijstWaarde(invulwaarde='D1549.72',
                                     label='D1549.72',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1549.72'),
        'D1550.12': KeuzelijstWaarde(invulwaarde='D1550.12',
                                     label='D1550.12',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1550.12'),
        'D1550.52': KeuzelijstWaarde(invulwaarde='D1550.52',
                                     label='D1550.52',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1550.52'),
        'D1550.92': KeuzelijstWaarde(invulwaarde='D1550.92',
                                     label='D1550.92',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1550.92'),
        'D1551.32': KeuzelijstWaarde(invulwaarde='D1551.32',
                                     label='D1551.32',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1551.32'),
        'D1551.72': KeuzelijstWaarde(invulwaarde='D1551.72',
                                     label='D1551.72',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1551.72'),
        'D1552.12': KeuzelijstWaarde(invulwaarde='D1552.12',
                                     label='D1552.12',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1552.12'),
        'D1552.52': KeuzelijstWaarde(invulwaarde='D1552.52',
                                     label='D1552.52',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1552.52'),
        'D1552.93': KeuzelijstWaarde(invulwaarde='D1552.93',
                                     label='D1552.93',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1552.93'),
        'D1553.33': KeuzelijstWaarde(invulwaarde='D1553.33',
                                     label='D1553.33',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1553.33'),
        'D1553.73': KeuzelijstWaarde(invulwaarde='D1553.73',
                                     label='D1553.73',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1553.73'),
        'D1554.13': KeuzelijstWaarde(invulwaarde='D1554.13',
                                     label='D1554.13',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1554.13'),
        'D1554.54': KeuzelijstWaarde(invulwaarde='D1554.54',
                                     label='D1554.54',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1554.54'),
        'D1554.94': KeuzelijstWaarde(invulwaarde='D1554.94',
                                     label='D1554.94',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1554.94'),
        'D1555.34': KeuzelijstWaarde(invulwaarde='D1555.34',
                                     label='D1555.34',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1555.34'),
        'D1555.75': KeuzelijstWaarde(invulwaarde='D1555.75',
                                     label='D1555.75',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1555.75'),
        'D1556.15': KeuzelijstWaarde(invulwaarde='D1556.15',
                                     label='D1556.15',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1556.15'),
        'D1556.55': KeuzelijstWaarde(invulwaarde='D1556.55',
                                     label='D1556.55',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1556.55'),
        'D1556.96': KeuzelijstWaarde(invulwaarde='D1556.96',
                                     label='D1556.96',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1556.96'),
        'D1557.36': KeuzelijstWaarde(invulwaarde='D1557.36',
                                     label='D1557.36',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1557.36'),
        'D1557.77': KeuzelijstWaarde(invulwaarde='D1557.77',
                                     label='D1557.77',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1557.77'),
        'D1558.17': KeuzelijstWaarde(invulwaarde='D1558.17',
                                     label='D1558.17',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1558.17'),
        'D1558.58': KeuzelijstWaarde(invulwaarde='D1558.58',
                                     label='D1558.58',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1558.58'),
        'D1558.98': KeuzelijstWaarde(invulwaarde='D1558.98',
                                     label='D1558.98',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1558.98'),
        'D1559.39': KeuzelijstWaarde(invulwaarde='D1559.39',
                                     label='D1559.39',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1559.39'),
        'D1559.79': KeuzelijstWaarde(invulwaarde='D1559.79',
                                     label='D1559.79',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1559.79'),
        'D1560.20': KeuzelijstWaarde(invulwaarde='D1560.20',
                                     label='D1560.20',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1560.20'),
        'D1560.61': KeuzelijstWaarde(invulwaarde='D1560.61',
                                     label='D1560.61',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1560.61'),
        'D1561.01': KeuzelijstWaarde(invulwaarde='D1561.01',
                                     label='D1561.01',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1561.01'),
        'D1561.42': KeuzelijstWaarde(invulwaarde='D1561.42',
                                     label='D1561.42',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1561.42'),
        'D1561.83': KeuzelijstWaarde(invulwaarde='D1561.83',
                                     label='D1561.83',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1561.83'),
        'D1562.23': KeuzelijstWaarde(invulwaarde='D1562.23',
                                     label='D1562.23',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1562.23'),
        'D1562.64': KeuzelijstWaarde(invulwaarde='D1562.64',
                                     label='D1562.64',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1562.64'),
        'D1563.05': KeuzelijstWaarde(invulwaarde='D1563.05',
                                     label='D1563.05',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1563.05'),
        'D1563.45': KeuzelijstWaarde(invulwaarde='D1563.45',
                                     label='D1563.45',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1563.45'),
        'D1563.86': KeuzelijstWaarde(invulwaarde='D1563.86',
                                     label='D1563.86',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1563.86'),
        'D1564.27': KeuzelijstWaarde(invulwaarde='D1564.27',
                                     label='D1564.27',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1564.27'),
        'D1564.68': KeuzelijstWaarde(invulwaarde='D1564.68',
                                     label='D1564.68',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/D1564.68'),
        'NULL': KeuzelijstWaarde(invulwaarde='NULL',
                                 label='NULL',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/NULL'),
        'Other': KeuzelijstWaarde(invulwaarde='Other',
                                  label='Other',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/Other'),
        'elektrisch': KeuzelijstWaarde(invulwaarde='elektrisch',
                                       label='elektrisch',
                                       status='ingebruik',
                                       definitie='elektrisch',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/elektrisch'),
        'flex': KeuzelijstWaarde(invulwaarde='flex',
                                 label='flex',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortGolflengte/flex')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

