# coding=utf-8
from ...Classes.Onderdeel.BloemrijkGraslandGraslandfase4 import BloemrijkGraslandGraslandfase4


# Generated with OTLClassCreator. To modify: extend, do not edit
class Stroomdalgrasland(BloemrijkGraslandGraslandfase4):
    """G4b - cipreswolfsmelk, geoorde zuring, gestreepte klaver, grote tijm, handjesgras, harige ratelaar, hemelsleutel, kaal breukkruid, kleine pimpernel, kleine ratelaar, knikkende distel, knolbeemdgras, kruisdistel, kweekdravik, moeslook, ronde ooievaarsbek, rozetkruidkers, rozetsteenkers, sikkelklaver, slangenlook, smalle raai, tripmadam, veldsalie, viltganzerik, voorjaarszegge, wit en zacht vetkruid, zachte haver, zeepkruid."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomdalgrasland'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()
